---
Summary: Allow reference card without collecting it
Status: Ready
---

# Description

Where we've got a card reference appearing in the text of a field, we add it
to an implicit collection - to allow, for instance, creating an ordered backlog
on a card as a collection. Sometimes - we might want to refer to the card in
the description of the card, but not actually add it to the collection.

The goal is that by permitting `[[!card_index]]` (with the exclamation point)
that the reference will still be recognised, but the card not be added to the
collection.

# Cucumber

**GIVEN** a field containing a card reference in the form `[[!card_index]]`
**WHEN** that field is displayed
**THEN** the reference is formatted per the active configuration

**GIVEN** a card containing a card reference in the form `[[!card_index]]`
**WHEN** that cards collection is retrieved
**THEN** the card is not in the collection
